@@ -6,7 +6,7 @@ import logging.config
 from .consts import LOG_FILE
 
 
-__version__ = '3.5.3'
+__version__ = '3.6.1'
 
 
 dict_config = {
@@ -14,10 +14,12 @@ dict_config = {
     'disable_existing_loggers': False,
     'formatters': {
         'standard': {
-            'format': "[%(asctime)s %(levelname)s %(module)s] : %(message)s",
+            'format': ("[%(asctime)s %(name)s:%(lineno)d] "
+                       "[%(levelname)s]: %(message)s"),
         },
         'thread': {
-            'format': "[%(asctime)s %(levelname)s %(module)s %(thread)d] : %(message)s",
+            'format': ("[%(asctime)s %(name)s:%(lineno)d %(thread)d] "
+                       "[%(levelname)s]: %(message)s"),
         },
     },
     'handlers': {},
