@@ -185,6 +185,7 @@ def attach_attrs(app):
         from .theme import ThemeManager
         from .tips import TipsManager
         from .ui import Ui
+        from .tray import Tray
 
         # GUI 的一些辅助管理模块
         app.coll_mgr = CollectionManager(app)
@@ -201,6 +202,8 @@ def attach_attrs(app):
 
         app.browser = Browser(app)
         app.ui = Ui(app)
+        if app.config.ENABLE_TRAY:
+            app.tray = Tray(app)
         app.show_msg = app.ui.magicbox.show_msg
 
 
@@ -213,10 +216,19 @@ def create_app(config):
         from PyQt5.QtGui import QIcon, QPixmap
         from PyQt5.QtWidgets import QApplication, QWidget
 
+        try:
+            # HELP: QtWebEngineWidgets must be imported before a
+            # QCoreApplication instance is created
+            # TODO: add a command line option to control this import
+            import PyQt5.QtWebEngineWidgets  # noqa
+        except ImportError:
+            logger.info('import QtWebEngineWidgets failed')
+
         from feeluown.compat import QEventLoop
 
         q_app = QApplication(sys.argv)
-        q_app.setQuitOnLastWindowClosed(True)
+
+        q_app.setQuitOnLastWindowClosed(not config.ENABLE_TRAY)
         q_app.setApplicationName('FeelUOwn')
 
         app_event_loop = QEventLoop(q_app)
@@ -230,7 +242,11 @@ def create_app(config):
                 self.setObjectName('app')
                 QApplication.setWindowIcon(QIcon(QPixmap(APP_ICON)))
 
-            def closeEvent(self, e):
+            def closeEvent(self, _):
+                if not self.config.ENABLE_TRAY:
+                    self.exit()
+
+            def exit(self):
                 self.ui.mpv_widget.close()
                 event_loop = asyncio.get_event_loop()
                 event_loop.stop()
@@ -268,6 +284,8 @@ def init_app(app):
     app.plugin_mgr.scan()
     if app.mode & App.GuiMode:
         app.theme_mgr.initialize()
+        if app.config.ENABLE_TRAY:
+            app.tray.initialize()
         app.tips_mgr.show_random_tip()
         app.coll_uimgr.initialize()
         app.browser.initialize()
